var util = require('util');
var FilesMapping = require("./files-mapping");
var MarkupFilesParser = require('../markup-files-parser');
var utils = require('../utils');
var path = require("path");

/*
    This class used for mapping markup files (i.e: html, ftl).
    The mapping works by combine all the js code in the file, and map it in one piece.
*/

function MarkupFilesMapper(handlerParams, logger) {
    FilesMapping.apply(this, arguments);
}

util.inherits(MarkupFilesMapper, FilesMapping);

module.exports = MarkupFilesMapper;
MarkupFilesMapper.prototype._generateNewMappingForFile = function (fileObject, isBranchCoverage, isLastFile) {
    var that = this;
    var filename = fileObject.getFilename(this.logger);
    var fullname = fileObject.getFullFilename();
    filename = utils.adjustPathSlashes(filename);
    var fileSig = {
        filename: filename,
        methods: []
    };
    var oldContent = fileObject.getContent();
    var sourceMaps = fileObject.readSourceMaps(this.logger);
    var extension = path.extname(filename);
    if (utils.isMarkupFile(extension)) {
         return that._generateFileSignatureForMarkupFile(fullname, filename, oldContent, sourceMaps,
             isBranchCoverage, isLastFile, fileSig);
    }
    return that._generateFileSignature(fullname, filename, oldContent, sourceMaps, isBranchCoverage,
        isLastFile, fileSig);
};

MarkupFilesMapper.prototype._generateFileSignatureForMarkupFile = function (fullname, filename, oldContent, sourceMaps,
                                                                            isBranchCoverage, isLastFile, fileSig) {
    var handler = new MarkupFilesParser(oldContent, fullname, this.logger);
    handler.extractScriptTags();
    var scriptTags = handler.scriptTags;
    if(!scriptTags || scriptTags.length === 0){
        this.logger.info("No script tags found in '%s'" , fullname);
        return {hasError: true};
    }
    var jsCodeInFile = handler.getAllJsInFile();
    return this._generateFileSignature(fullname, filename, jsCodeInFile, sourceMaps, isBranchCoverage, isLastFile, fileSig);
};